aboutsummaryrefslogtreecommitdiff
path: root/gcc/loop.h
diff options
context:
space:
mode:
authorKazu Hirata <kazu@cs.umass.edu>2002-09-22 14:09:34 +0000
committerKazu Hirata <kazu@gcc.gnu.org>2002-09-22 14:09:34 +0000
commitcc2902df52a39b343d5094a39d3e6efb868015de (patch)
treed2db7ebbe3f404f7fa5e30b7ecf4ac4675f5b518 /gcc/loop.h
parent4bc38b68640a996a5a1a9e870a707836ca32bfa9 (diff)
downloadgcc-cc2902df52a39b343d5094a39d3e6efb868015de.zip
gcc-cc2902df52a39b343d5094a39d3e6efb868015de.tar.gz
gcc-cc2902df52a39b343d5094a39d3e6efb868015de.tar.bz2
dbxout.c: Follow spelling conventions.
* dbxout.c: Follow spelling conventions. * defaults.h: Likewise. * df.c: Likewise. * diagnostic.h: Likewise. * doloop.c: Likewise. * dwarf2out.c: Likewise. * dwarfout.c: Likewise. * emit-rtl.c: Likewise. * except.c: Likewise. * explow.c: Likewise. * expmed.c: Likewise. * expr.c: Likewise. * expr.h: Likewise. * flags.h: Likewise. * flow.c: Likewise. * fold-const.c: Likewise. * function.c: Likewise. * function.h: Likewise. * gcc.c: Likewise. * gcov-io.h: Likewise. * gcov.c: Likewise. * gcse.c: Likewise. * genattrtab.c: Likewise. * genconfig.c: Likewise. * genrecog.c: Likewise. * ggc-page.c: Likewise. * ggc.h: Likewise. * global.c: Likewise. * gthr-win32.h: Likewise. * integrate.c: Likewise. * jump.c: Likewise. * langhooks.c: Likewise. * langhooks.h: Likewise. * line-map.h: Likewise. * local-alloc.c: Likewise. * longlong.h: Likewise. * loop.c: Likewise. * loop.h: Likewise. From-SVN: r57406
Diffstat (limited to 'gcc/loop.h')
-rw-r--r--gcc/loop.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc/loop.h b/gcc/loop.h
index 13b6293..d5fe043 100644
--- a/gcc/loop.h
+++ b/gcc/loop.h
@@ -145,7 +145,7 @@ struct induction
same biv register. */
struct induction *same; /* If this giv has been combined with another
giv, this points to the base giv. The base
- giv will have COMBINED_WITH non-zero. */
+ giv will have COMBINED_WITH nonzero. */
HOST_WIDE_INT const_adjust; /* Used by loop unrolling, when an address giv
is split, and a constant is eliminated from
the address, the -constant is stored here
@@ -377,7 +377,7 @@ struct loop_info
struct loop_regs regs;
/* The induction variable information in loop. */
struct loop_ivs ivs;
/* Non-zero if call is in pre_header extended basic block. */
int pre_header_has_call;
};
@@ -377,7 +377,7 @@ struct loop_info
/* The induction variable information in loop. */
struct loop_ivs ivs;
- /* Non-zero if call is in pre_header extended basic block. */
+ /* Nonzero if call is in pre_header extended basic block. */
int pre_header_has_call;
};